import cv2
import os
from epic7_bot.templates.BaseTemplates import BaseTemplates
from epic7_bot.templates.Template import Template


class CommonTemplates(BaseTemplates):
    def __init__(self):
        super(self.__class__, self).__init__()

        self.skip_button: Template = {
            "image": cv2.imread(self.dirPath + '/../images/skip_button.png', 0),
            "name": "skip_button"
        }

        self.connecting_problem: Template = {
            "image": cv2.imread(self.dirPath + '/../images/connecting.png', 0),
            "name": "connecting_problem"
        }

        self.there_was_a_connection_error: Template = {
            "image": cv2.imread(self.dirPath + '/../images/there_was_a_connection_error.png', 0),
            "name": "there_was_a_connection_error"
        }

        self.dispatch_mission_completed: Template = {
            "image": cv2.imread(self.dirPath + '/../images/dispatch_mission_completed.png', 0),
            "name": "dispatch_mission_completed"
        }

        self.dispatch_mission: Template = {
            "image": cv2.imread(self.dirPath + '/../images/dispatch_mission.png', 0),
            "name": "dispatch_mission"
        }
